from distutils.core import setup

setup(
        name         = 'jlnester',
        version      = '1.0.0',
        py_modules   = ['jlnester'],
        author       = 'JiangLe',
        author_email = '2773394158@qq.com',
        url          = 'http://www.headfirstlabs.com',
        description  = 'A simple printer of nested lists',
)